@@ -1073,71 +1073,6 @@ examples:
         az afd rule-set delete -g group --rule-set-name ruleset1 --profile-name profile
 """
 
-helps['afd rule'] = """
-type: group
-short-summary: Manage delivery rules within the specified rule set.
-"""
-
-helps['afd rule create'] = """
-type: command
-short-summary: Creates a new delivery rule within the specified rule set.
-examples:
-  - name: Create a rule to append a response header for requests from Thailand.
-    text: >
-        az afd rule create -g group --rule-set-name ruleset1 --profile-name profile --order 2 --match-variable RemoteAddress --operator GeoMatch --match-values TH
-        --rule-name disablecaching --action-name ModifyResponseHeader --header-action Append --header-name X-CDN --header-value AFDX
-  - name: Create a rule for http to https redirect
-    text: >
-        az afd rule create -g group --rule-set-name ruleset1 --profile-name profile --order 1
-        --rule-name "redirect" --match-variable RequestScheme --operator Equal --match-values HTTP
-        --action-name "UrlRedirect" --redirect-protocol Https --redirect-type Moved
-"""
-
-helps['afd rule delete'] = """
-type: command
-short-summary: Remove a delivery rule from rule set.
-examples:
-  - name: Remove a rule with name rule1.
-    text: >
-        az afd rule delete -g group --rule-set-name ruleSetName --profile-name profile --rule-name rule1
-"""
-
-helps['afd rule show'] = """
-type: command
-short-summary: Show delivery rule details.
-examples:
-  - name: show details of the delivery rule with name rule1.
-    text: >
-        az afd rule show -g group --rule-set-name ruleSetName --profile-name profile --rule-name rule1
-"""
-
-helps['afd rule condition'] = """
-type: group
-short-summary: Manage delivery rule conditions for a rule.
-"""
-
-helps['afd rule condition list'] = """
-type: command
-short-summary: show condtions associated with the rule.
-examples:
-  - name: show condtions associated with the rule.
-    text: >
-        az afd rule condition list -g group --rule-set-name ruleSetName --profile-name profile --rule-name name
-"""
-
-helps['afd rule action'] = """
-type: group
-short-summary: Manage delivery rule actions for a rule.
-"""
-helps['afd rule action list'] = """
-type: command
-short-summary: show actions associated with the rule.
-examples:
-  - name: show actions associated with the rule.
-    text: >
-        az afd rule action list -g group --rule-set-name ruleSetName --profile-name profile --rule-name name
-"""
-
 helps['afd log-analytic'] = """
 type: group
 short-summary: Manage afd log analytic results.
