@@ -47,6 +47,9 @@ def load_arguments(self, _):
                    help="Specifies the fallback application type as public client, such as an installed application "
                         "running on a mobile device. The default value is false which means the fallback application "
                         "type is confidential client such as a web app.")
+        c.argument('service_management_reference',
+                   help='References application or service contact information from a Service or Asset Management '
+                        'database.')
         c.argument('sign_in_audience',
                    arg_type=get_enum_type(['AzureADMyOrg', 'AzureADMultipleOrgs', 'AzureADandPersonalMicrosoftAccount',
                                            'PersonalMicrosoftAccount']),
@@ -321,7 +324,7 @@ def load_arguments(self, _):
         c.argument('condition', is_preview=True, min_api='2020-04-01-preview', help='Condition under which the user can be granted permission.')
         c.argument('condition_version', is_preview=True, min_api='2020-04-01-preview', help='Version of the condition syntax. If --condition is specified without --condition-version, default to 2.0.')
         c.argument('assignment_name', name_arg_type,
-                   help='A GUID for the role assignment. It must be unique and different for each role assignment. If omitted, a new GUID is generetd.')
+                   help='A GUID for the role assignment. It must be unique and different for each role assignment. If omitted, a new GUID is generated.')
 
     time_help = ('The {} of the query in the format of %Y-%m-%dT%H:%M:%SZ, e.g. 2000-12-31T12:59:59Z. Defaults to {}')
     with self.argument_context('role assignment list-changelogs') as c:
