@@ -600,7 +600,7 @@ def load_command_table(self, _):
             pass
 
     with self.command_group('capacity reservation group', capacity_reservation_groups_sdk, min_api='2021-04-01',
-                            client_factory=cf_capacity_reservation_groups, is_preview=True) as g:
+                            client_factory=cf_capacity_reservation_groups) as g:
         g.custom_command('create', 'create_capacity_reservation_group')
         g.custom_command('update', 'update_capacity_reservation_group')
         g.custom_show_command('show', 'show_capacity_reservation_group')
@@ -610,7 +610,7 @@ def load_command_table(self, _):
         self.command_table['capacity reservation group list'] = CapacityReservationGroupList(loader=self)
 
     with self.command_group('capacity reservation', capacity_reservations_sdk, min_api='2021-04-01',
-                            client_factory=cf_capacity_reservations, is_preview=True) as g:
+                            client_factory=cf_capacity_reservations) as g:
         g.custom_command('create', 'create_capacity_reservation', supports_no_wait=True)
         g.custom_command('update', 'update_capacity_reservation', supports_no_wait=True)
         g.custom_show_command('show', 'show_capacity_reservation')
