@@ -6,6 +6,7 @@ import abc
 import copy
 
 from azure.cli.core import azclierror
+from azure.cli.core.commands.arm import add_usage, remove_usage, set_usage
 from knack.arguments import CLICommandArgument, CaseInsensitiveList
 from knack.preview import PreviewItem
 from knack.experimental import ExperimentalItem
@@ -83,7 +84,7 @@ class AAZArgEnum:
             try:
                 data_type = type(values[0])
                 value = data_type(data)
-                logger.warning("Use extended value `%s` outside choices {self.to_choices()}.", str(value))
+                logger.warning("Use extended value '%s' outside choices %s.", str(value), self.to_choices())
                 return value
             except (ValueError, IndexError):
                 pass
@@ -96,7 +97,7 @@ class AAZBaseArg(AAZBaseType):
 
     def __init__(self, options=None, required=False, help=None, arg_group=None, is_preview=False, is_experimental=False,
                  id_part=None, default=AAZUndefined, blank=AAZUndefined, nullable=False, fmt=None, registered=True,
-                 configured_default=None):
+                 configured_default=None, completer=None):
         """
 
         :param options: argument optional names.
@@ -113,6 +114,7 @@ class AAZBaseArg(AAZBaseType):
         :param fmt: argument format
         :param registered: control whether register argument into command display
         :param configured_default: the key to retrieve the default value from cli configuration
+        :param completer: tab completion if completion is active
         """
         super().__init__(options=options, nullable=nullable)
         self._help = {}  # the key in self._help can be 'name', 'short-summary', 'long-summary', 'populator-commands'
@@ -134,6 +136,7 @@ class AAZBaseArg(AAZBaseType):
         self._fmt = fmt
         self._registered = registered
         self._configured_default = configured_default
+        self._completer = completer
 
     def to_cmd_arg(self, name, **kwargs):
         """ convert AAZArg to CLICommandArgument """
@@ -202,6 +205,11 @@ class AAZBaseArg(AAZBaseType):
         if self._configured_default:
             arg.configured_default = self._configured_default
 
+        if self._completer:
+            from azure.cli.core.decorators import Completer
+            assert isinstance(self._completer, Completer)
+            arg.completer = self._completer
+
         action = self._build_cmd_action()   # call sub class's implementation to build CLICommandArgument action
         if action:
             arg.action = action
@@ -485,20 +493,22 @@ class AAZResourceGroupNameArg(AAZStrArg):
             help="Name of resource group. "
                  "You can configure the default group using `az configure --defaults group=<name>`",
             configured_default='group',
+            completer=None,
             **kwargs):
+        from azure.cli.core.commands.parameters import get_resource_group_completion_list
+        completer = completer or get_resource_group_completion_list
         super().__init__(
             options=options,
             id_part=id_part,
             help=help,
             configured_default=configured_default,
+            completer=completer,
             **kwargs
         )
 
     def to_cmd_arg(self, name, **kwargs):
-        from azure.cli.core.commands.parameters import get_resource_group_completion_list
         from azure.cli.core.local_context import LocalContextAttribute, LocalContextAction, ALL
         arg = super().to_cmd_arg(name, **kwargs)
-        arg.completer = get_resource_group_completion_list
         arg.local_context_attribute = LocalContextAttribute(
             name='resource_group_name',
             actions=[LocalContextAction.SET, LocalContextAction.GET],
@@ -515,18 +525,22 @@ class AAZResourceLocationArg(AAZStrArg):
                  "You can configure the default location using `az configure --defaults location=<location>`.",
             fmt=None,
             configured_default='location',
+            completer=None,
             **kwargs):
+        from azure.cli.core.commands.parameters import get_location_completion_list
+
         fmt = fmt or AAZResourceLocationArgFormat()
+        completer = completer or get_location_completion_list
         super().__init__(
             options=options,
             help=help,
             fmt=fmt,
             configured_default=configured_default,
+            completer=completer,
             **kwargs
         )
 
     def to_cmd_arg(self, name, **kwargs):
-        from azure.cli.core.commands.parameters import get_location_completion_list
         from azure.cli.core.local_context import LocalContextAttribute, LocalContextAction, ALL
         arg = super().to_cmd_arg(name, **kwargs)
         if self._required and \
@@ -539,7 +553,6 @@ class AAZResourceLocationArg(AAZStrArg):
             short_summary += "When not specified, the location of the resource group will be used."
             arg.help = short_summary
 
-        arg.completer = get_location_completion_list
         arg.local_context_attribute = LocalContextAttribute(
             name='location',
             actions=[LocalContextAction.SET, LocalContextAction.GET],
@@ -562,20 +575,18 @@ class AAZSubscriptionIdArg(AAZStrArg):
             self, help="Name or ID of subscription. You can configure the default subscription "
                        "using `az account set -s NAME_OR_ID`",
             fmt=None,
+            completer=None,
             **kwargs):
+        from azure.cli.core._completers import get_subscription_id_list
         fmt = fmt or AAZSubscriptionIdArgFormat()
+        completer = completer or get_subscription_id_list
         super().__init__(
             help=help,
             fmt=fmt,
+            completer=completer,
             **kwargs
         )
 
-    def to_cmd_arg(self, name, **kwargs):
-        from azure.cli.core._completers import get_subscription_id_list
-        arg = super().to_cmd_arg(name, **kwargs)
-        arg.completer = get_subscription_id_list
-        return arg
-
 
 class AAZFileArg(AAZStrArg):
 
@@ -616,12 +627,11 @@ class AAZGenericUpdateArg(AAZBaseArg, AAZListType):
 
 
 class AAZGenericUpdateSetArg(AAZGenericUpdateArg):
-    _example = '--set property1.property2=<value>'
 
     def __init__(
             self, options=('--set',), arg_group='Generic Update',
             help='Update an object by specifying a property path and value to set.'
-                 '  Example: {}'.format(_example),
+                 '  Example: {}'.format(set_usage),
             **kwargs):
         super().__init__(
             options=options,
@@ -643,12 +653,11 @@ class AAZGenericUpdateSetArg(AAZGenericUpdateArg):
 
 
 class AAZGenericUpdateAddArg(AAZGenericUpdateArg):
-    _example = '--add property.listProperty <key=value, string or JSON string>'
 
     def __init__(
             self, options=('--add',), arg_group='Generic Update',
             help='Add an object to a list of objects by specifying a path and key value pairs.'
-                 '  Example: {}'.format(_example),
+                 '  Example: {}'.format(add_usage),
             **kwargs):
         super().__init__(
             options=options,
@@ -670,12 +679,11 @@ class AAZGenericUpdateAddArg(AAZGenericUpdateArg):
 
 
 class AAZGenericUpdateRemoveArg(AAZGenericUpdateArg):
-    _example = '--remove property.list <indexToRemove> OR --remove propertyToRemove'
 
     def __init__(
             self, options=('--remove', ), arg_group='Generic Update',
             help='Remove a property or an element from a list.'
-                 '  Example: {}'.format(_example),
+                 '  Example: {}'.format(remove_usage),
             **kwargs):
         super().__init__(
             options=options,
