@@ -22,8 +22,7 @@ except ImportError:
 shorthand_help_messages = {
     "show-help": 'Try "??" to show more.',
     "short-summary": 'Support shorthand-syntax, json-file and yaml-file.',
-    "long-summary": 'See https://github.com/Azure/azure-cli/tree/dev/doc/shorthand_syntax.md '
-                    'for more about shorthand syntax.'
+    "long-summary": 'See https://aka.ms/cli-shorthand for more about shorthand syntax.'
 }
 
 
