@@ -13,12 +13,11 @@ from knack.log import get_logger
 from knack.util import CLIError
 from msal import PublicClientApplication, ConfidentialClientApplication
 
+from .constants import AZURE_CLI_CLIENT_ID
 from .msal_credentials import UserCredential, ServicePrincipalCredential
 from .persistence import load_persisted_token_cache, file_extensions, load_secret_store
 from .util import check_result
 
-AZURE_CLI_CLIENT_ID = '04b07795-8ddb-461a-bbee-02f9e1bf7b46'
-
 # Service principal entry properties. Names are taken from OAuth 2.0 client credentials flow parameters:
 # https://learn.microsoft.com/en-us/entra/identity-platform/v2-oauth2-client-creds-grant-flow
 _TENANT = 'tenant'
@@ -38,6 +37,10 @@ WAM_PROMPT = (
     "Select the account you want to log in with. "
     "For more information on login with Azure CLI, see https://go.microsoft.com/fwlink/?linkid=2271136")
 
+PASSWORD_CERTIFICATE_WARNING = (
+    "Passing the service principal certificate with `--password` is deprecated and will be removed "
+    "by version 2.74. Please use `--certificate` instead.")
+
 logger = get_logger(__name__)
 
 
@@ -304,7 +307,9 @@ class ServicePrincipalAuth:  # pylint: disable=too-many-instance-attributes
         return ServicePrincipalAuth(entry)
 
     @classmethod
-    def build_credential(cls, secret_or_certificate=None, client_assertion=None, use_cert_sn_issuer=None):
+    def build_credential(cls, secret_or_certificate=None,
+                         certificate=None, use_cert_sn_issuer=None,
+                         client_assertion=None):
         """Build credential from user input. The credential looks like below, but only one key can exist.
         {
             'client_secret': 'my_secret',
@@ -313,9 +318,15 @@ class ServicePrincipalAuth:  # pylint: disable=too-many-instance-attributes
         }
         """
         entry = {}
-        if secret_or_certificate:
+        if certificate:
+            entry[_CERTIFICATE] = os.path.expanduser(certificate)
+            if use_cert_sn_issuer:
+                entry[_USE_CERT_SN_ISSUER] = use_cert_sn_issuer
+        elif secret_or_certificate:
+            # TODO: Make secret_or_certificate secret only
             user_expanded = os.path.expanduser(secret_or_certificate)
             if os.path.isfile(user_expanded):
+                logger.warning(PASSWORD_CERTIFICATE_WARNING)
                 entry[_CERTIFICATE] = user_expanded
                 if use_cert_sn_issuer:
                     entry[_USE_CERT_SN_ISSUER] = use_cert_sn_issuer
